/*  This file is part of mastodonpp.
 *  Copyright © 2020 tastytea <tastytea@tastytea.de>
 *
 *  This program is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU Affero General Public License as published by
 *  the Free Software Foundation, version 3.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Affero General Public License for more details.
 *
 *  You should have received a copy of the GNU Affero General Public License
 *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

#ifndef MASTODONPP_INSTANCE_HPP
#define MASTODONPP_INSTANCE_HPP

#include <string>

namespace mastodonpp
{

using std::string;

/*!
 *  @brief  Holds the hostname and access token of an instance.
 *
 *  @since  0.1.0
 */
class Instance
{
public:
    /*!
     *  @brief  Construct a new Instance object.
     *
     *  @param  instance     The hostname of the instance.
     *  @param  access_token Your access token.
     *
     *  @since  0.1.0
     */
    explicit Instance(string instance, string access_token);

private:
    const string _instance;
    string _access_token;
};

} // namespace mastodonpp

#endif  // MASTODONPP_INSTANCE_HPP
